import{t as o,a as i,b as a,c,i as d,T as p,j as u,P as _,C as f,M as l,s as g,k as s,l as m,m as y,n as v,p as b}from"./outputWidgets.e822ff0f.js";import{u as w,s as h,a as r}from"./index.7c28b641.js";import"./pubsub.ae710ef5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4239959c-2d14-49a4-9cd7-66ce3f15516f",e._sentryDebugIdIdentifier="sentry-dbid-4239959c-2d14-49a4-9cd7-66ce3f15516f")}catch{}})();const I={};function k(e,t){const n=i("router-view");return a(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=o(I,[["render",k]]);class P{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await Promise.all([w(),h()]);const e=d({render:()=>m(x)});p.init(),u(e,r),P.init(),e.use(r),e.use(_),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",l),e.component("Message",g),s(e,y),s(e,v),s(e,b)})();
//# sourceMappingURL=player.e8f082b7.js.map
