import{d as B,eB as k,eA as w,G as I,a as h,b as r,c as d,w as a,eG as j,f as i,u as e,eu as c,eC as z,aq as g,eD as x,a_ as C,ew as D,bu as A,cF as S}from"./outputWidgets.e822ff0f.js";import{B as $}from"./BaseLayout.24b42efe.js";import{a as E}from"./asyncComputed.68870ff7.js";import{a as M,_ as N}from"./component.vue_vue_type_script_setup_true_lang.4592753b.js";import"./router.8fbd98d9.js";import"./index.3b830ff3.js";import{P}from"./project.49fc286a.js";import{O as R}from"./organization.4f94a2b2.js";import{B as V,a as F,c as G}from"./index.e8141e2b.js";import{c as L}from"./Text.4c9d53a2.js";import"./gateway.349a9491.js";import"./icons.0ab0d55f.js";import"./index.3873cc30.js";import"./Base.775de4d5.js";import"./transButton.f06af665.js";import"./Title.5afb3003.js";import"./index.bf8163eb.js";import"./record.edca104e.js";import"./pubsub.ae710ef5.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[s]="61bb6917-b4a8-4794-aba8-e02d108feabb",n._sentryDebugIdIdentifier="sentry-dbid-61bb6917-b4a8-4794-aba8-e02d108feabb")}catch{}})();const O={key:0},T={key:2},ue=B({__name:"Build",setup(n){const s=k(),p=w(),m=s.params.buildId,{result:t,loading:b}=E(async()=>{const o=await M(m);if(!o)throw new Error("Build not found");const u=await P.get(o.projectId),l=await R.get(u.organizationId);return j({bs:o,project:u,organization:l})}),f=I(()=>!b.value&&t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.organization.name,path:`/organizations/${t.value.organization.id}`},{label:`Build ${m.split("-")[0]}`,path:`/projects/${t.value.project.id}/builds`}]:void 0);function y(){var o;(o=t.value)!=null&&o.project.id&&p.push({name:"builds",params:{projectId:t.value.project.id}})}return(o,u)=>{const l=h("router-link");return r(),d($,null,{navbar:a(()=>[i(e(G),{title:"Inspect Build",style:{padding:"5px 10px"},onBack:y},{breadcrumb:a(()=>[f.value?(r(),d(e(V),{key:0},{default:a(()=>[(r(!0),c(C,null,z(f.value,(_,v)=>(r(),d(e(F),{key:v},{default:a(()=>[i(l,{to:_.path},{default:a(()=>[g(x(_.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):D("",!0)]),_:1})]),content:a(()=>[e(b)?(r(),c("div",O,[i(e(A))])):e(t)?(r(),d(N,{key:1,"build-spec":e(t).bs},null,8,["build-spec"])):(r(),c("div",T,[i(e(S),{direction:"vertical"},{default:a(()=>[i(e(L),null,{default:a(()=>[g("Could not find build")]),_:1})]),_:1})]))]),_:1})}}});export{ue as default};
//# sourceMappingURL=Build.8d0a6c8a.js.map
