import"./outputWidgets.e822ff0f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="7d8475be-aa99-496c-a572-1e859d12da48",e._sentryDebugIdIdentifier="sentry-dbid-7d8475be-aa99-496c-a572-1e859d12da48")}catch{}})();const r=e=>{try{return new URL(e),!0}catch{return!1}};export{r as i};
//# sourceMappingURL=url.c786ab78.js.map
