import{t,b as s,eu as a}from"./outputWidgets.e822ff0f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="1612ab0f-2aa9-40f1-a105-63792b367e81",e._sentryDebugIdIdentifier="sentry-dbid-1612ab0f-2aa9-40f1-a105-63792b367e81")}catch{}})();const o={},r={class:"organization-settings"};function i(e,n){return s(),a("div",r,"Organization settings")}const c=t(o,[["render",i]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.2889426b.js.map
