import{cz as n}from"./outputWidgets.e822ff0f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="d978ebfb-ae69-46e0-a4e5-e6aa8cf2f083",e._sentryDebugIdIdentifier="sentry-dbid-d978ebfb-ae69-46e0-a4e5-e6aa8cf2f083")}catch{}})();const t=(e,r)=>{n.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.7b2bb5e9.js.map
