import"./outputWidgets.e822ff0f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="e17df655-0507-4dd9-9864-64584c253e5d",e._sentryDebugIdIdentifier="sentry-dbid-e17df655-0507-4dd9-9864-64584c253e5d")}catch{}})();function r(e,d){const i=document,n=e.matched.slice().reverse().find(t=>t.meta&&t.meta.title),s=d.matched.slice().reverse().find(t=>t.meta&&t.meta.metaTags);n?i.title=n.meta.title:s&&(i.title=s.meta.title)}export{r as u};
//# sourceMappingURL=index.bf8163eb.js.map
