import{U as s}from"./outputWidgets.e822ff0f.js";import{c as i,d as f}from"./index.17f6a7b6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="4f3910b7-8f21-4c84-acfa-b1fc34346c49",e._sentryDebugIdIdentifier="sentry-dbid-4f3910b7-8f21-4c84-acfa-b1fc34346c49")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:d,TimePicker:m,QuarterPicker:c,RangePicker:o}=i(f),y=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:d,RangePicker:o,TimePicker:m,QuarterPicker:c,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(t.name,t),e.component(r.name,r),e.component(c.name,c),e)});export{y as D,t as M,c as Q,o as R,r as W};
//# sourceMappingURL=dayjs.27643810.js.map
