import{F as I,r as R,g as B,R as P}from"./FormRunner.3993f75f.js";import{d as q,eB as x,eA as F,F as D,H as i,G as y,u as p,b as s,eu as u,f as E,c as S,eE as K,eF as L,e as c,t as N}from"./outputWidgets.e822ff0f.js";import{u as h}from"./uuid.2994880b.js";import{a as A}from"./asyncComputed.68870ff7.js";import{L as C}from"./CircularLoading.c2a83eb7.js";import"./url.c786ab78.js";import"./index.7c28b641.js";import"./pubsub.ae710ef5.js";import"./icons.0ab0d55f.js";import"./PlayerNavbar.101bb2a2.js";import"./ActionButton.vue_vue_type_script_setup_true_lang.a778a11a.js";import"./WidgetsFrame.8afe7997.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="e1e021d7-46b5-46c1-8be1-166de15d0ab0",o._sentryDebugIdIdentifier="sentry-dbid-e1e021d7-46b5-46c1-8be1-166de15d0ab0")}catch{}})();const d=o=>(K("data-v-1e2a2c24"),o=o(),L(),o),T={key:0,class:"loading"},V={key:1,class:"error"},G=d(()=>c("h1",null,"Oops! Something went wrong",-1)),H=d(()=>c("p",null,"An unknown error ocurred. Please try again or contact support.",-1)),O=[G,H],j={key:2,class:"form"},z={key:3,class:"error not-found"},J=d(()=>c("h1",null,"Page not found",-1)),M=d(()=>c("p",null,"The page you requested could not be found.",-1)),Q=[J,M],U=q({__name:"Player",setup(o){const t=x(),l=F(),_=D({playerKey:h()});i(t,()=>w());function v(e,a){R("player",l,e,a)}const g=({path:e})=>{l.push({name:"player",query:t.query,params:{path:e.split("/")}})},m=async()=>{_.playerKey=h()};i([()=>t.path,()=>t.query],()=>m());const{loading:b,result:r,error:k,refetch:w}=A(()=>{var e;return B((e=t.path.slice(1))!=null?e:"")}),f=y(()=>n.value?P.create(n.value.id):null),n=y(()=>{var e,a;return(a=(e=r.value)==null?void 0:e.form)!=null?a:null});return i(r,()=>{var e;!r.value||r.value.form&&(document.title=(e=r.value.form.welcomeTitle)!=null?e:r.value.form.title)}),(e,a)=>p(b)?(s(),u("div",T,[E(C)])):p(k)?(s(),u("div",V,O)):n.value&&f.value?(s(),u("div",j,[(s(),S(I,{key:_.playerKey,class:"player",form:n.value,"is-preview":!1,params:p(t).query,broker:f.value,"enable-auto-focus":!0,onNavigate:g,onLogout:m,onRedirect:v},null,8,["form","params","broker"]))])):(s(),u("div",z,Q))}});const ue=N(U,[["__scopeId","data-v-1e2a2c24"]]);export{ue as default};
//# sourceMappingURL=Player.20b7a984.js.map
