import{d,eB as b,G as m,a as g,b as f,c as v,w as r,f as s}from"./outputWidgets.e822ff0f.js";import{B as h}from"./BaseLayout.24b42efe.js";import{a as _}from"./asyncComputed.68870ff7.js";import"./router.8fbd98d9.js";import"./index.3b830ff3.js";import{P as y}from"./project.49fc286a.js";import{O as z}from"./organization.4f94a2b2.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.be210b7c.js";import{S as I}from"./Sidebar.ef92e3c2.js";import{y as w,z as B,A as k,B as C,C as P,D as $,q as x,E as D,F as L,u as M,v as O,x as S}from"./icons.0ab0d55f.js";import"./Base.775de4d5.js";import"./transButton.f06af665.js";import"./Text.4c9d53a2.js";import"./Title.5afb3003.js";import"./index.bf8163eb.js";import"./record.edca104e.js";import"./pubsub.ae710ef5.js";import"./gateway.349a9491.js";import"./logo.084e5d7c.js";import"./index.e8141e2b.js";import"./Tooltip.e58f5500.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="50b226b2-e916-47c6-a55c-d017394ab53f",o._sentryDebugIdIdentifier="sentry-dbid-50b226b2-e916-47c6-a55c-d017394ab53f")}catch{}})();const ta=d({__name:"Project",setup(o){const c=b().params.projectId,{result:a}=_(()=>y.get(c).then(async e=>{const t=await z.get(e.organizationId);return{project:e,organization:t}})),l=m(()=>{var e,t,n,p;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=a.value)==null?void 0:p.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),u=m(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Live",path:"live",icon:w},{name:"Builds",path:"builds",icon:B},{name:"Connectors",path:"connectors",icon:k},{name:"Tables",path:"tables",icon:C},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:$},{name:"Files",path:"files",icon:x},{name:"Logs",icon:D,path:"logs",beta:!0},{name:"Settings",icon:L,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:M,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:O,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:S,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=g("router-view");return f(),v(h,null,{content:r(()=>[s(n)]),navbar:r(()=>[s(j,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:r(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{ta as default};
//# sourceMappingURL=Project.598a7169.js.map
