import{ee as c,ab as p,U as s,f as d,O as y}from"./outputWidgets.e822ff0f.js";import{B as b,a as u}from"./Base.775de4d5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="9494fe73-8d2f-405e-826f-c4eef9c4696a",e._sentryDebugIdIdentifier="sentry-dbid-9494fe73-8d2f-405e-826f-c4eef9c4696a")}catch{}})();var g=globalThis&&globalThis.__rest||function(e,o){var n={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&o.indexOf(t)<0&&(n[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var r=0,t=Object.getOwnPropertySymbols(e);r<t.length;r++)o.indexOf(t[r])<0&&Object.prototype.propertyIsEnumerable.call(e,t[r])&&(n[t[r]]=e[t[r]]);return n};const m=c(1,2,3,4,5),_=()=>s(s({},y(u(),["component","strong"])),{level:Number}),l=(e,o)=>{let{slots:n,attrs:t}=o;const{level:r=1}=e,f=g(e,["level"]);let a;m.includes(r)?a=`h${r}`:(p(),a="h1");const i=s(s(s({},f),{component:a}),t);return d(b,i,n)};l.displayName="ATypographyTitle";l.inheritAttrs=!1;l.props=_();const T=l;export{T as A};
//# sourceMappingURL=Title.5afb3003.js.map
