import"./outputWidgets.e822ff0f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="20e1fa70-ff84-4671-9319-d63b71fe9d72",e._sentryDebugIdIdentifier="sentry-dbid-20e1fa70-ff84-4671-9319-d63b71fe9d72")}catch{}})();function d(e){return e.charAt(0).toUpperCase()+e.slice(1)}function a(e,r){const n=e.toLocaleLowerCase().replace(/[^a-z0-9]/g,"_").replace(/_+/g,"_");return r?n:n.replace(/_$/,"")}export{d as c,a as n};
//# sourceMappingURL=string.5881666a.js.map
