import{S as c}from"./Sidebar.ef92e3c2.js";import{_ as p}from"./Navbar.vue_vue_type_script_setup_true_lang.be210b7c.js";import{u as d,v as l,x as u}from"./icons.0ab0d55f.js";import{d as b,eB as f,G as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.e822ff0f.js";import{a as w}from"./asyncComputed.68870ff7.js";import"./router.8fbd98d9.js";import"./index.3b830ff3.js";import{O as z}from"./organization.4f94a2b2.js";import{B as h}from"./BaseLayout.24b42efe.js";import"./Tooltip.e58f5500.js";import"./logo.084e5d7c.js";import"./index.e8141e2b.js";import"./transButton.f06af665.js";import"./Text.4c9d53a2.js";import"./Base.775de4d5.js";import"./Title.5afb3003.js";import"./index.bf8163eb.js";import"./record.edca104e.js";import"./pubsub.ae710ef5.js";import"./gateway.349a9491.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[a]="d3ba9240-1c75-4139-acdb-3d95cc0dd007",o._sentryDebugIdIdentifier="sentry-dbid-d3ba9240-1c75-4139-acdb-3d95cc0dd007")}catch{}})();const J=b({__name:"Organization",setup(o){const n=f().params.organizationId,{result:e}=w(()=>z.get(n)),i=g(()=>e.value?[{label:"My organizations",path:"/organizations"},{label:e.value.name,path:`/organizations/${e.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(p,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(c,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{J as default};
//# sourceMappingURL=Organization.2f39efb9.js.map
